package com.dgtis.common.redis.configure;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.dgtis.system.api.model.LoginUser;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.type.TypeFactory;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.SerializationException;
import com.alibaba.fastjson.parser.ParserConfig;
import org.springframework.util.Assert;
import java.nio.charset.Charset;

/**
 * Redis使用FastJson序列化
 * 
 * @author dgtis
 */
public class FastJson2JsonRedisSerializer<T> implements RedisSerializer<T>
{
    @SuppressWarnings("unused")
    private ObjectMapper objectMapper = new ObjectMapper();

    public static final Charset DEFAULT_CHARSET = Charset.forName("UTF-8");

    private Class<T> clazz;

    static
    {
        ParserConfig.getGlobalInstance().setAutoTypeSupport(true);
        // 2022/5/24 陆光晨 start 2022/5/23FastJson爆出autoType漏洞，需要将jar包升级到1.2.68及以上并设置safeMode为true
        ParserConfig.getGlobalInstance().setSafeMode(true);
        ParserConfig.getGlobalInstance().addAutoTypeCheckHandler(autoTypeCheckHandler());
        // 2022/5/24 陆光晨 end 2022/5/23FastJson爆出autoType漏洞，需要将jar包升级到1.2.68及以上并设置safeMode为true
    }
    public static ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler() {
        return new ParserConfig.AutoTypeCheckHandler() {

            @Override
            public Class<?> handler(String typeName, Class<?> expectClass, int features) {
                if ("com.dgtis.system.api.model.LoginUser".equals(typeName)
                        || "LoginUser".equals(typeName)) {
                    return LoginUser.class;
                } else {
                    try {
                        return Class.forName(typeName);
                    } catch (ClassNotFoundException e) {
                        throw new IllegalArgumentException(e);
                    }
                }
            }
        };
    }

    public FastJson2JsonRedisSerializer(Class<T> clazz)
    {
        super();
        this.clazz = clazz;
    }

    @Override
    public byte[] serialize(T t) throws SerializationException
    {
        if (t == null)
        {
            return new byte[0];
        }
        return JSON.toJSONString(t, SerializerFeature.WriteClassName).getBytes(DEFAULT_CHARSET);
    }

    @Override
    public T deserialize(byte[] bytes) throws SerializationException
    {
        if (bytes == null || bytes.length <= 0)
        {
            return null;
        }
        String str = new String(bytes, DEFAULT_CHARSET);

        return JSON.parseObject(str, clazz);
    }

    public void setObjectMapper(ObjectMapper objectMapper)
    {
        Assert.notNull(objectMapper, "'objectMapper' must not be null");
        this.objectMapper = objectMapper;
    }

    protected JavaType getJavaType(Class<?> clazz)
    {
        return TypeFactory.defaultInstance().constructType(clazz);
    }
}
